@@ -1,3 +1,4 @@
+# flake8: noqa E501
 from django.apps import apps
 from django.conf import settings as django_settings
 from django.test.signals import setting_changed
@@ -21,7 +22,7 @@ class ObjDict(dict):
                 val = [import_string(v) if isinstance(v, str) else v for v in val]
             self[item] = val
         except KeyError:
-            val = super(ObjDict, self).__getattribute__(item)
+            val = super().__getattribute__(item)
 
         return val
 
@@ -73,6 +74,9 @@ default_settings = {
             "username_reset": "djoser.email.UsernameResetEmail",
         }
     ),
+    "EMAIL_FRONTEND_DOMAIN": None,
+    "EMAIL_FRONTEND_PROTOCOL": None,
+    "EMAIL_FRONTEND_SITE_NAME": None,
     "CONSTANTS": ObjDict({"messages": "djoser.constants.Messages"}),
     "LOGOUT_ON_PASSWORD_CHANGE": False,
     "CREATE_SESSION_ON_LOGIN": False,
@@ -96,6 +100,17 @@ default_settings = {
             "token_destroy": ["rest_framework.permissions.IsAuthenticated"],
         }
     ),
+    "WEBAUTHN": ObjDict(
+        {
+            "RP_NAME": "localhost",
+            "RP_ID": "localhost",
+            "ORIGIN": "http://localhost:8000",
+            "CHALLENGE_LENGTH": 32,
+            "UKEY_LENGTH": 20,
+            "SIGNUP_SERIALIZER": "djoser.webauthn.serializers.WebauthnCreateUserSerializer",
+            "LOGIN_SERIALIZER": "djoser.webauthn.serializers.WebauthnLoginSerializer",
+        }
+    ),
 }
 
 SETTINGS_TO_IMPORT = ["TOKEN_MODEL", "SOCIAL_AUTH_TOKEN_STRATEGY"]
