@@ -31,7 +31,7 @@ def logout_user(request):
         logout(request)
 
 
-class ActionViewMixin(object):
+class ActionViewMixin:
     def post(self, request, **kwargs):
         serializer = self.get_serializer(data=request.data)
         serializer.is_valid(raise_exception=True)
