@@ -5,6 +5,7 @@ from rest_framework import generics, status, views, viewsets
 from rest_framework.decorators import action
 from rest_framework.exceptions import NotFound
 from rest_framework.response import Response
+from rest_framework.serializers import Serializer
 
 from djoser import signals, utils
 from djoser.compat import get_user_email
@@ -14,9 +15,7 @@ User = get_user_model()
 
 
 class TokenCreateView(utils.ActionViewMixin, generics.GenericAPIView):
-    """
-    Use this endpoint to obtain user authentication token.
-    """
+    """Use this endpoint to obtain user authentication token."""
 
     serializer_class = settings.SERIALIZERS.token_create
     permission_classes = settings.PERMISSIONS.token_create
@@ -30,10 +29,9 @@ class TokenCreateView(utils.ActionViewMixin, generics.GenericAPIView):
 
 
 class TokenDestroyView(views.APIView):
-    """
-    Use this endpoint to logout user (remove user authentication token).
-    """
+    """Use this endpoint to logout user (remove user authentication token)."""
 
+    serializer_class = Serializer
     permission_classes = settings.PERMISSIONS.token_destroy
 
     def post(self, request):
@@ -132,8 +130,8 @@ class UserViewSet(viewsets.ModelViewSet):
     def get_instance(self):
         return self.request.user
 
-    def perform_create(self, serializer):
-        user = serializer.save()
+    def perform_create(self, serializer, *args, **kwargs):
+        user = serializer.save(*args, **kwargs)
         signals.user_registered.send(
             sender=self.__class__, user=user, request=self.request
         )
@@ -145,11 +143,15 @@ class UserViewSet(viewsets.ModelViewSet):
         elif settings.SEND_CONFIRMATION_EMAIL:
             settings.EMAIL.confirmation(self.request, context).send(to)
 
-    def perform_update(self, serializer):
-        super().perform_update(serializer)
+    def perform_update(self, serializer, *args, **kwargs):
+        super().perform_update(serializer, *args, **kwargs)
         user = serializer.instance
+        signals.user_updated.send(
+            sender=self.__class__, user=user, request=self.request
+        )
+
         # should we send activation email after update?
-        if settings.SEND_ACTIVATION_EMAIL:
+        if settings.SEND_ACTIVATION_EMAIL and not user.is_active:
             context = {"user": user}
             to = [get_user_email(user)]
             settings.EMAIL.activation(self.request, context).send(to)
@@ -201,12 +203,13 @@ class UserViewSet(viewsets.ModelViewSet):
         serializer.is_valid(raise_exception=True)
         user = serializer.get_user(is_active=False)
 
-        if not settings.SEND_ACTIVATION_EMAIL or not user:
+        if not settings.SEND_ACTIVATION_EMAIL:
             return Response(status=status.HTTP_400_BAD_REQUEST)
 
-        context = {"user": user}
-        to = [get_user_email(user)]
-        settings.EMAIL.activation(self.request, context).send(to)
+        if user:
+            context = {"user": user}
+            to = [get_user_email(user)]
+            settings.EMAIL.activation(self.request, context).send(to)
 
         return Response(status=status.HTTP_204_NO_CONTENT)
 
@@ -258,7 +261,7 @@ class UserViewSet(viewsets.ModelViewSet):
             settings.EMAIL.password_changed_confirmation(self.request, context).send(to)
         return Response(status=status.HTTP_204_NO_CONTENT)
 
-    @action(["post"], detail=False, url_path="set_{}".format(User.USERNAME_FIELD))
+    @action(["post"], detail=False, url_path=f"set_{User.USERNAME_FIELD}")
     def set_username(self, request, *args, **kwargs):
         serializer = self.get_serializer(data=request.data)
         serializer.is_valid(raise_exception=True)
@@ -273,7 +276,7 @@ class UserViewSet(viewsets.ModelViewSet):
             settings.EMAIL.username_changed_confirmation(self.request, context).send(to)
         return Response(status=status.HTTP_204_NO_CONTENT)
 
-    @action(["post"], detail=False, url_path="reset_{}".format(User.USERNAME_FIELD))
+    @action(["post"], detail=False, url_path=f"reset_{User.USERNAME_FIELD}")
     def reset_username(self, request, *args, **kwargs):
         serializer = self.get_serializer(data=request.data)
         serializer.is_valid(raise_exception=True)
@@ -286,9 +289,7 @@ class UserViewSet(viewsets.ModelViewSet):
 
         return Response(status=status.HTTP_204_NO_CONTENT)
 
-    @action(
-        ["post"], detail=False, url_path="reset_{}_confirm".format(User.USERNAME_FIELD)
-    )
+    @action(["post"], detail=False, url_path=f"reset_{User.USERNAME_FIELD}_confirm")
     def reset_username_confirm(self, request, *args, **kwargs):
         serializer = self.get_serializer(data=request.data)
         serializer.is_valid(raise_exception=True)
